# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: snailjob.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'snailjob.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0esnailjob.proto\"p\n\x08Metadata\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\'\n\x07headers\x18\x07 \x03(\x0b\x32\x16.Metadata.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"O\n\x13GrpcSnailJobRequest\x12\r\n\x05reqId\x18\x01 \x01(\x03\x12\x1b\n\x08metadata\x18\x02 \x01(\x0b\x32\t.Metadata\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\"J\n\nGrpcResult\x12\r\n\x05reqId\x18\x01 \x01(\x03\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\t2A\n\x0cUnaryRequest\x12\x31\n\x0cunaryRequest\x12\x14.GrpcSnailJobRequest\x1a\x0b.GrpcResultb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'snailjob_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_METADATA_HEADERSENTRY']._loaded_options = None
  _globals['_METADATA_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_METADATA']._serialized_start=18
  _globals['_METADATA']._serialized_end=130
  _globals['_METADATA_HEADERSENTRY']._serialized_start=84
  _globals['_METADATA_HEADERSENTRY']._serialized_end=130
  _globals['_GRPCSNAILJOBREQUEST']._serialized_start=132
  _globals['_GRPCSNAILJOBREQUEST']._serialized_end=211
  _globals['_GRPCRESULT']._serialized_start=213
  _globals['_GRPCRESULT']._serialized_end=287
  _globals['_UNARYREQUEST']._serialized_start=289
  _globals['_UNARYREQUEST']._serialized_end=354
# @@protoc_insertion_point(module_scope)
